<?php

namespace Drupal\tellstick\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\tellstick\TellstickLiveService;
use Drupal\tellstick\TellstickService;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Form controller for Tellstick edit forms.
 *
 * @ingroup tellstick
 */
class TellstickSensorUpdateController extends ControllerBase {

  /**
   * The Telstick Live service.
   *
   * @var \Drupal\tellstick\TelltickLiveService
   */
  protected $tellstickLiveService;

  /**
   * The Tellstick service.
   *
   * @var \Drupal\tellstick\TelltickService
   */
  protected $tellstickService;

  /**
   * The constructor.
   *
   * @param \Drupal\tellstick\TellstickService $tellstick_service
   *   The Service connector.
   * @param \Drupal\tellstick\TellstickLiveService $tellstick_live_service
   *   The Live Service connector.
   */
  public function __construct(TellstickService $tellstick_service,
                              TellstickLiveService $tellstick_live_service) {
    $this->tellstickService = $tellstick_service;
    $this->tellstickLiveService = $tellstick_live_service;
  }

  /**
   * Create a new intance of the Controller.
   *
   * @param Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The container connector.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tellstick'),
      $container->get('tellstick.live')
    );
  }

  /**
   * Update the Tellstick sensor.
   */
  public function updateTellstickSensors() {

    $sensorCount = 0;
    $updateCount = 0;

    // Get all sensors known by Telldus Live.
    $sxe = $this->tellstickLiveService->getTellstickLiveSensors();
    if ($sxe->getName() == 'sensors') {
      foreach ($sxe->children() as $child) {
        $sensors = $child->attributes();
        $id = (string) $sensors['id'];
        $sensor = $this->tellstickService->getTellstickSensorById($id);

        if (!empty($sensor)) {
          // Count all sensors worked through.
          $sensorCount = $sensorCount + 1;
          // Count all sensors actually updated.
          if ($sensor->get('changed')->value >
            \Drupal::state()->get('tellstick.sensor_update')) {
            $updateCount = $updateCount + 1;
          }
        }
      }
    }
    // Save the last run time for this Controller.
    \Drupal::state()->set('tellstick.sensor_update', REQUEST_TIME);
    // Set message with number of sensors imported.
    $message = $this->t('A total of @updateCount sensor(s) updated out of @sensorCount checked.', [
      '@sensorCount' => $sensorCount,
      '@updateCount' => $updateCount,
    ]);
    $this->messenger()->addStatus($message);
    return new RedirectResponse(
      Url::fromRoute('entity.tellstick_sensor.collection')->toString());
  }

}
