<?php

namespace Drupal\tellstick\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * A form to set Tellstick Live credentials and
 * generic settings.
 */
class TellstickSettingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tellstick.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tellstick_setting_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tellstick.settings');

    $form['live_credentials'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! credentials'),
    ];

    $url = Url::fromUri('https://api.telldus.com/keys/index');
    $link = Link::fromTextAndUrl('https://api.telldus/keys/index', $url)
      ->toString();
    $form['live_credentials']['tellstick_information'] = [
      '#markup' => '<p>' . $this->t('Please get your own set of keys at') .
      ' ' . $link . '</p>',
    ];

    $form['live_credentials']['public_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tellstick Public Key'),
      '#default_value' => $config->get('public_key'),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => $this->t('Your Tellstick Public Key.'),
      '#required' => TRUE,
    ];

    $form['live_credentials']['private_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tellstick Private Key'),
      '#default_value' => $config->get('private_key'),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => $this->t('Your Tellstick Private Key.'),
      '#required' => TRUE,
    ];
    $form['live_credentials']['token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tellstick Token'),
      '#default_value' => $config->get('token'),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => $this->t('Your Tellstick Token.'),
      '#required' => TRUE,
    ];
    $form['live_credentials']['token_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tellstick Token Secret'),
      '#default_value' => $config->get('token_secret'),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => $this->t('Your Tellstick Token Secret.'),
      '#required' => TRUE,
    ];
    $form['live_access'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! access method'),
    ];
    $form['live_access']['access_method'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select Telldus Live! access method'),
      '#options' => [0 => 'http://', 1 => 'https://'],
      '#default_value' => $config->get('access_method'),
      '#description' => $this->t('Select your prefered access method. Please NOTE that https:// might lock up your Drupal if your certificate is not working!'),
    ];
    $form['hidden_sensors'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! hidden sensors'),
    ];
    $form['hidden_sensors']['include_hidden'] = [
      '#type' => 'radios',
      '#title' => $this->t('Include or exclude the hidden sensors from Telldus Live!'),
      '#options' => [1 => 'Include', 0 => 'Exclude'],
      '#default_value' => $config->get('include_hidden'),
      '#description' => $this->t('Do you want to include the hidden sensors from Telldus Live!?'),
    ];
    $form['database_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! database settings'),
    ];
    $form['database_settings']['database_lifetime'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Telldus Live! database lifetime'),
      '#options' => [
        0 => 'Forever',
        1 => '1 day',
        7 => '1 week',
        30 => ' 1 month',
        90 => '3 months',
        180 => '6 months',
      ],
      '#default_value' => $config->get('database_lifetime'),
      '#description' => $this->t('Select for how long you will keep your sensors data in the database. Requres an active cron to work.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('tellstick.settings')
      ->set('public_key',
        $form_state->getValue('public_key'))
      ->save();
    $this->config('tellstick.settings')
      ->set('private_key',
        $form_state->getValue('private_key'))
      ->save();
    $this->config('tellstick.settings')
      ->set('token', $form_state->getValue('token'))
      ->save();
    $this->config('tellstick.settings')
      ->set('token_secret',
        $form_state->getValue('token_secret'))
      ->save();
    $this->config('tellstick.settings')
      ->set('access_method',
        $form_state->getValue('access_method'))
      ->save();
    $this->config('tellstick.settings')
      ->set('include_hidden',
        $form_state->getValue('include_hidden'))
      ->save();
    $this->config('tellstick.settings')
      ->set('database_lifetime',
        $form_state->getValue('database_lifetime'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
