<?php

namespace Drupal\tellstick\Plugin\views\sort;

use Drupal\views\Plugin\views\sort\SortPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A field that displays the sensor raw data in different ways.
 *
 * @ingroup views_sort_handlers
 *
 * @ViewsSort("ssensor")
 */
class TellstickHandlerSortSensor extends SortPluginBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    if (isset($this->definition['sortType'])) {
      $options['sortType'] = [
        'default' => $this->definition['sortType'],
      ];
    }
    else {
      $options['sortType'] = [
        'default' => 'weight',
      ];
    }
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['sortType'] = [
      '#type' => 'radios',
      '#title' => $this->t('Sensor sort order'),
      '#options' => [
        'id' => $this->t('By id'),
        'name' => $this->t('By name'),
        'weight' => $this->t('By weight'),
      ],
      '#description' => $this->t('Sort by sensor id, name or by the same weight as used for the block.'),
      '#default_value' => $this->options['sortType'],
    ];
  }

  /**
   * Called to add the sort to a query.
   */
  public function query() {
    list($table, $field) = explode(".", $this->getField());
    switch ($this->options['sortType']) {
      case 'id':
      default:
        $this->query->addOrderBy($table, 'id', $this->options['order']);
        return;

      case 'name':
        $this->query->addOrderBy($table, 'sensor', $this->options['order']);
        return;

      case 'weight':
        $formula = views_date_sql_format('YmdH', "$table.$field");
        return;
    }

    // Add the field.
    $this->query->addOrderBy(NULL, $formula, $this->options['order'], $table . '_' . $field . '_' . $this->options['sortType']);
  }

}
